@@ -32,8 +32,8 @@ class FilesProcessor(AbstractProcessor):
                 logging.debug("Skipping file '%s'", file)
                 continue
 
-            all_branches = self.gitlab.get_branches(project_and_group)
             if configuration["files"][file]["branches"] == "all":
+                all_branches = self.gitlab.get_branches(project_and_group)
                 branches = sorted(all_branches)
             elif configuration["files"][file]["branches"] == "protected":
                 protected_branches = self.gitlab.get_protected_branches(
@@ -41,6 +41,7 @@ class FilesProcessor(AbstractProcessor):
                 )
                 branches = sorted(protected_branches)
             else:
+                all_branches = self.gitlab.get_branches(project_and_group)
                 branches = []
                 for branch in configuration["files"][file]["branches"]:
                     if branch in all_branches:
@@ -56,12 +57,21 @@ class FilesProcessor(AbstractProcessor):
             for branch in branches:
                 cli_ui.debug(f"Processing file '{file}' in branch '{branch}'")
 
+                if configuration.get(
+                    "files|" + file + "|content"
+                ) and configuration.get("files|" + file + "|file"):
+                    cli_ui.error(
+                        f"File '{file}' in '{project_and_group}' has both `content` and `file` set - "
+                        "use only one of these keys."
+                    )
+                    sys.exit(EXIT_INVALID_INPUT)
+
                 # unprotect protected branch temporarily for operations below
                 if configuration.get("branches|" + branch + "|protected"):
                     logging.debug(
                         "> Temporarily unprotecting the branch for managing files in it..."
                     )
-                    self.gitlab.unprotect_branch(project_and_group, branch)
+                    self.branch_protector.unprotect_branch(project_and_group, branch)
 
                 if configuration.get("files|" + file + "|delete"):
                     try:
@@ -85,21 +95,14 @@ class FilesProcessor(AbstractProcessor):
                 else:
                     # change or create file
 
-                    if configuration.get(
-                        "files|" + file + "|content"
-                    ) and configuration.get("files|" + file + "|file"):
-                        cli_ui.error(
-                            f"File '{file}' in '{project_and_group}' has both `content` and `file` set - "
-                            "use only one of these keys."
-                        )
-                        sys.exit(EXIT_INVALID_INPUT)
-                    elif configuration.get("files|" + file + "|content"):
+                    if configuration.get("files|" + file + "|content"):
                         new_content = configuration.get("files|" + file + "|content")
                     else:
                         path_in_config = Path(
                             configuration.get("files|" + file + "|file")
                         )
                         if path_in_config.is_absolute():
+                            # TODO: does this work? we are reading the content twice in this case...
                             path = path_in_config.read_text()
                         else:
                             # relative paths are relative to config file location
